
.. image:: https://landscape.io/github/ivandeex/hero-crawl/master/landscape.svg?style=flat
   :target: https://landscape.io/github/ivandeex/hero-crawl/master
   :alt: Code Health

.. image:: https://requires.io/github/ivandeex/hero-crawl/requirements.svg?branch=master
    :target: https://requires.io/github/ivandeex/hero-crawl/requirements/?branch=master
    :alt: Requirements Status

.. image:: https://badge.fury.io/py/hero-crawl.svg
    :target: https://badge.fury.io/py/hero-crawl
    :alt: PyPi Package

.. image:: https://img.shields.io/pypi/pyversions/hero-crawl.svg
    :target: https://pypi.python.org/pypi/hero-crawl
    :alt: Supported Python Versions


Hero Crawl
==========

Collection of reusable utilities for awesome Scrapy_ and `Flask Admin`_ frameworks on `Heroku`_.

.. _Scrapy: https://scrapy.org/doc/
.. _`Flask Admin`: https://flask-admin.readthedocs.io/en/latest/
.. _Heroku: https://www.heroku.com/

Requirements
============

* Python 2.7.10+

Install
=======

The quick way::

    pip install hero-crawl

License
=======

MIT
